# intake-astro

[![Build Status](https://travis-ci.org/ContinuumIO/intake-astro.svg?branch=master)](https://travis-ci.org/ContinuumIO/intake-astro)

Read the `documentaion <https://intake-astro.readthedocs.io/>`_.

Astronomy Plugins for Intake:

- fits-array
- fits-table
